AsymmetricKeyPair class abstract

Represents an AsymmetricKeyPair format

Inheritance
Implementers

Constructors

AsymmetricKeyPair.create(String publicKey, String privateKey)

Properties

atPrivateKey AtPrivateKey
no setterinherited
atPublicKey AtPublicKey
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited