AtChopsUtil class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateAtEncryptionKeyPair(
{int keySize = 2048}) → AtEncryptionKeyPair - Generates AtEncryption asymmetric keypair with default size 2048 bits
-
generateAtPkamKeyPair(
{int keySize = 2048}) → AtPkamKeyPair - Generates AtEncryption asymmetric keypair with default size 2048 bits
-
generateECKeyPair(
) → ECKeypair - Generates EC keypair
-
generateEd25519KeyPair(
) → Future< SimpleKeyPair> - Generates an symmetric keypair for ED25519 elliptic curve signing and verification
-
generateIVFromBase64String(
String ivBase64) → InitialisationVector -
generateIVLegacy(
) → InitialisationVector -
generateMlDsa65KeyPair(
) → Future< AtMlDsa65KeyPair> - Generates an ML-DSA-65 key pair for post-quantum digital signatures.
-
generateMlKem768KeyPair(
) → Future< AtMlKem768KeyPair> - Generates an ML-KEM-768 key pair for post-quantum key encapsulation.
-
generateRandomIV(
int length) → InitialisationVector - Generates a random initialisation vector from a given length Length must be 0 to 16
-
generateRSAKeyPair(
{int keySize = 2048}) → RSAKeypair - Generates RSA keypair with default size 2048 bits
-
generateSymmetricKey(
EncryptionKeyType keyType) → SymmetricKey -
Generates symmetric AES key based on
keyType -
generateX25519KeyPair(
) → Future< AtX25519KeyPair> - Generates an X25519 key pair for Diffie–Hellman key agreement.
-
generateXWingKeyPair(
) → Future< AtXWingKeyPair> - Generates an X-Wing hybrid post-quantum/traditional KEM key pair (draft-connolly-cfrg-xwing-kem; X25519 + ML-KEM-768).