AtEncryptionResult class

Annotations
  • @Deprecated('Use the direct encryption algorithm result bytes instead. This ' 'compatibility API will be removed in the next major release.')

Constructors

AtEncryptionResult()

Properties

atEncryptionMetaData AtEncryptionMetaData
getter/setter pair
atEncryptionResultType AtEncryptionResultType
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
result ↔ dynamic
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited