AtKeysCrypto class abstract

An abstract class that provides cryptographic operations for AtKeys using specific hashing algorithms.

This class allows for encryption and decryption of AtKeys with a passphrase, using the provided hashing algorithm type.

Annotations

Constructors

AtKeysCrypto()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decrypt(AtEncrypted atEncrypted, String passPhrase, {HashParams? hashParams}) FutureOr<String>
Decrypts the given atEncrypted object back to its original plain text format using the provided passPhrase and optional hashParams.
encrypt(String plainAtKeys, String passPhrase, {HashParams? hashParams}) FutureOr<AtEncrypted>
Encrypts the given plainAtKeys using the provided passPhrase and optional hashParams.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromHashingAlgorithm(HashingAlgoType hashingAlgoType) AtKeysCrypto
Returns an instance of _AtKeysCryptoImpl based on the provided hashingAlgoType.