AtSigningAlgorithm class abstract

Interface for data signing. Data is signed using private key from a key pair. Signed data signature is verified with public key of the key pair.

Do not implement for new code. Implement AtSignatureAlgorithm instead — it is stateless (key material passed per call) and safe to share as a singleton.

Removed in v4. Will become sealed once all implementers move into this library, closing the hierarchy in favor of AtSignatureAlgorithm.

Implementers
Annotations
  • @Deprecated('Removed in v4. Use AtSignatureAlgorithm instead.')
  • @sealed

Constructors

AtSigningAlgorithm()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(Uint8List data) FutureOr<Uint8List>
Signs the data using private key of asymmetric key pair
toString() String
A string representation of this object.
inherited
verify(Uint8List signedData, Uint8List signature, {String? publicKey}) FutureOr<bool>
Verifies the data signature using public key of asymmetric key pair or the passed publicKey

Operators

operator ==(Object other) bool
The equality operator.
inherited