AtXWingKeyPair class

Inheritance
Annotations
  • @Deprecated('Use XWingKeyPair instead. This compatibility wrapper will be removed ' 'in the next major release.')

Constructors

AtXWingKeyPair.create(String publicKey, String privateKey)

Properties

atPrivateKey AtPrivateKey
no setterinherited
atPublicKey AtPublicKey
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
privateKeyBytes Uint8List
The raw private key bytes (atPrivateKey base64-decoded).
no setterinherited
publicKeyBytes Uint8List
The raw public key bytes (atPublicKey base64-decoded).
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited