DefaultHash class

Implemented types
Annotations
  • @Deprecated('Use Md5HashingAlgo instead. This compatibility wrapper will be removed ' 'in the next major release.')

Constructors

DefaultHash()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

hash(List<int> data, {covariant HashParams? hashParams}) String
Creates a combined hash code for a number of objects.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited