Ed25519SigningAlgo class

Data signing and verification for Ed25519 - elliptic curve algorithm Keypair for the algorithm has to generated using AtChopsUtil.generateEd25519KeyPair()

Implemented types

Constructors

Ed25519SigningAlgo()

Properties

ed25519KeyPair ← SimpleKeyPair
no getter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(Uint8List data) Future<Uint8List>
Signs the data using private key of asymmetric key pair
override
toString() String
A string representation of this object.
inherited
verify(Uint8List signedData, Uint8List signature, {String? publicKey}) Future<bool>
Verifies the data signature using public key of asymmetric key pair or the passed publicKey
override

Operators

operator ==(Object other) bool
The equality operator.
inherited