HmacSha256 class

HMAC-SHA256 (RFC 2104). The keyed-hash primitive HKDF is built on; also usable directly for MACs. Wraps package:crypto so consumers depend only on at_chops for keyed hashing.

Constructors

HmacSha256()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

compute(Uint8List key, Uint8List data) Uint8List
HMAC-SHA256(key, data) → 32 raw bytes.