HmacSha384 class

HMAC-SHA384 (RFC 2104). The keyed-hash primitive HkdfSha384 is built on.

Constructors

HmacSha384()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

compute(Uint8List key, Uint8List data) Uint8List
HMAC-SHA384(key, data) -> 48 raw bytes.