PkamSigningAlgo class

Data signing and verification for Public Key Authentication Mechanism - Pkam

Implemented types
Annotations
  • @Deprecated('Use RsaSignatureAlgo with the appropriate key material instead. This ' 'compatibility API will be removed in the next major release.')

Constructors

PkamSigningAlgo(AtPkamKeyPair? _pkamKeyPair, HashingAlgoType _hashingAlgoType)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(Uint8List data) Uint8List
Signs the data using private key of asymmetric key pair
override
toString() String
A string representation of this object.
inherited
verify(Uint8List signedData, Uint8List signature, {String? publicKey}) bool
Verifies the data signature using public key of asymmetric key pair or the passed publicKey
override

Operators

operator ==(Object other) bool
The equality operator.
inherited