RsaEncryptionAlgo class
- Implemented types
Constructors
- RsaEncryptionAlgo()
- RsaEncryptionAlgo.fromKeyPair(RsaKeyPair? _encryptionKeypair)
Properties
- atPrivateKey ↔ AtPrivateKey?
-
getter/setter pairoverride
- atPublicKey ↔ AtPublicKey?
-
getter/setter pairoverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decrypt(
Uint8List encryptedData) → Uint8List -
Decrypt
encryptedDatawithatPrivateKey.privateKeyoverride -
encrypt(
Uint8List plainData) → Uint8List -
Encrypt
plainDatawithatPublicKey.publicKeyoverride -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited