AtKeyAgreementAlgorithm class abstract

Interface for a Diffie–Hellman key agreement primitive such as X25519.

Implementers

Constructors

AtKeyAgreementAlgorithm()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dh(Uint8List privateKey, Uint8List peerPublicKey) FutureOr<Uint8List>
Compute the shared secret from privateKey and peerPublicKey.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited