PaddingParams class

A class that defines parameters for padding algorithms used in AES encryption.

The PaddingParams class provides configurable parameters required for padding algorithms, such as the block size. These parameters are used to ensure that data conforms to the block size required by AES encryption.

Constructors

PaddingParams()

Properties

blockSize int
The block size (in bytes) used for padding.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited