Argon2idHashingAlgo class
A class that implements the Argon2id hashing algorithm for password hashing.
This class provides a method to hash a given password using the Argon2id algorithm, which is a memory-hard, CPU-intensive key derivation function suitable for password hashing and encryption key derivation.
The class uses the cryptography package's Argon2id algorithm for deriving
a key from a password and encodes the result into a Base64 string.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
hash(
String password, {covariant ArgonHashParams? hashParams}) → Future< String> -
Hashes a given password using the Argon2id algorithm.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited