ArgonHashParams class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
hashLength
↔ int
-
The length of the resulting hash in bytes.
getter/setter pair
-
iterations
↔ int
-
The number of iterations (time cost) applied during the hashing process.
getter/setter pair
-
memory
↔ int
-
The amount of memory (in KB) to be used during the hashing process.
getter/setter pair
-
parallelism
↔ int
-
The degree of parallelism, representing the number of threads used during hashing.
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
salt
↔ List<int>?
-
The Argon2id salt.
getter/setter pair
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited