AtEncryptionMetaData class
Class which represents metadata for encryption/decryption.
- Annotations
-
- @Deprecated('Use the direct encryption algorithm result bytes and your own metadata ' 'instead. This compatibility API will be removed in the next major ' 'release.')
Constructors
- AtEncryptionMetaData(String atEncryptionAlgorithm, EncryptionKeyType encryptionKeyType)
Properties
- atEncryptionAlgorithm ↔ String
-
getter/setter pair
- encryptionKeyType ↔ EncryptionKeyType
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- iv ↔ InitialisationVector?
-
getter/setter pair
- keyName ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited