AtKeysCrypto class abstract
An abstract class that provides cryptographic operations for AtKeys using specific hashing algorithms.
This class allows for encryption and decryption of AtKeys with a passphrase, using the provided hashing algorithm type.
- Annotations
-
- @Deprecated('This will be moved to at_auth')
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decrypt(
AtEncrypted atEncrypted, String passPhrase, {HashParams? hashParams}) → FutureOr< String> -
Decrypts the given
atEncryptedobject back to its original plain text format using the providedpassPhraseand optionalhashParams. -
encrypt(
String plainAtKeys, String passPhrase, {HashParams? hashParams}) → FutureOr< AtEncrypted> -
Encrypts the given
plainAtKeysusing the providedpassPhraseand optionalhashParams. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromHashingAlgorithm(
HashingAlgoType hashingAlgoType) → AtKeysCrypto -
Returns an instance of
_AtKeysCryptoImplbased on the providedhashingAlgoType.