DefaultSigningAlgo class
Data signing and verification using atsign encryption keypair Allowed algorithms are listed in SigningAlgoType and HashingAlgoType
- Implemented types
Constructors
- DefaultSigningAlgo(AtEncryptionKeyPair? _encryptionKeyPair, HashingAlgoType _hashingAlgoType)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sign(
Uint8List data) → Uint8List -
Signs the data using private key of asymmetric key pair
override
-
toString(
) → String -
A string representation of this object.
inherited
-
verify(
Uint8List signedData, Uint8List signature, {String? publicKey}) → bool -
Verifies the data signature using public key of asymmetric key pair or the passed
publicKeyoverride
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited