RawKeyPairBytes mixin
Raw-byte accessors for key pairs whose AtPublicKey/AtPrivateKey strings hold base64-encoded raw key bytes (not DER/PEM) — the PQ and X25519 key pairs. Not for the RSA-family pairs, whose strings are base64-encoded DER.
- Superclass constraints
- Mixin applications
Properties
- atPrivateKey → AtPrivateKey
-
no setterinherited
- atPublicKey → AtPublicKey
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- privateKeyBytes → Uint8List
-
The raw private key bytes (atPrivateKey base64-decoded).
no setter
- publicKeyBytes → Uint8List
-
The raw public key bytes (atPublicKey base64-decoded).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited