types library

Classes

AbstractKey
Represents abstract format all keys should be in.
AbstractKeyPair
Represents abstract format of a keyPair
ArgonHashParams
ASymmetricEncryptionAlgorithm
Interface for asymmetric encryption algorithms. Check DefaultEncryptionAlgo for sample implementation.
AsymmetricKeyPair
Represents an AsymmetricKeyPair format
AtEncryptionAlgorithm<T, V>
Interface for encrypting and decrypting data. Check DefaultEncryptionAlgo for sample implementation.
AtHashingAlgorithm<K, V>
Interface for hashing data. Refer DefaultHash for sample implementation.
AtKemAlgorithm
Interface for a Key Encapsulation Mechanism (KEM) such as ML-KEM-768.
AtKeyAgreementAlgorithm
Interface for a Diffie–Hellman key agreement primitive such as X25519.
AtPrivateKey
Represents a private key from AtKeyPair
AtPublicKey
Represents a public key from AtKeyPair
AtSigningAlgorithm
Interface for data signing. Data is signed using private key from a key pair Signed data signature is verified with public key of the key pair.
DefaultHashParams
HashParams
A class that holds the parameters for configuring a hashing algorithm.
InitialisationVector
KeyNames
PaddingAlgorithm
An abstract class that defines a padding algorithm for AES encryption and decryption.
PaddingParams
A class that defines parameters for padding algorithms used in AES encryption.
SymmetricEncryptionAlgorithm<T, V>
Interface for symmetric encryption algorithms. Check AESEncryptionAlgo for sample implementation.
SymmetricKey
Represent a key for symmetric key encryption/decryption