AtKemAlgorithm class abstract
Interface for a Key Encapsulation Mechanism (KEM) such as ML-KEM-768.
A KEM does not encrypt arbitrary data. It produces a shared secret that both parties can derive — the sender via encapsulate against the recipient's public key, the recipient via decapsulate using their secret key and the ciphertext sent by the sender.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decapsulate(
Uint8List secretKey, Uint8List ciphertext) → FutureOr< Uint8List> -
Recover the shared secret from
ciphertextusingsecretKey. -
encapsulate(
Uint8List publicKey) → FutureOr< ({Uint8List ciphertext, Uint8List sharedSecret})> -
Encapsulate a fresh shared secret against
publicKey. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited